from distutils.core import setup

#从python的发布工具导入setup函数



setup(

    name= 'zdcb',

    version= '1.0.0',

    #关联模块

    py_modules =['zdc'],

    author= 'lqh',

    author_email='11@189.com',

    url='https://upload.pypi.org/1egacy/',

    description= '处理列表数据'

)